prepend_avro_header

Function prepend_avro_header 

pub fn prepend_avro_header(schema_version_id: Uuid, payload: &[u8]) -> Vec<u8> 
Frame payload with the Glue Avro header, producing a buffer suitable to publish to Kafka. The header is laid down using the uncompressed framing (compression = 0x00).